<?php

$EM_CONF['sg_estate_base'] = array(
    'title' => 'sg.estate - Base',
    'description' => 'Base Extension (Search, List, Detail and Contact) for sg_estate',
    'category' => 'plugin',
    'author' => 'Marc Saleiko, Daniel Hoffmann',
    'author_email' => 'saleiko@smply.gd, hoffmann@smply.gd',
    'author_company' => 'smply.gd GmbH',
    'state' => 'beta',
    'internal' => '',
    'uploadfolder' => '0',
    'clearCacheOnLoad' => 0,
    'version' => '10.0.0',
    'constraints' => array(
        'depends' => array(
            'typo3' => '10.4.4-10.4.99',
            'sg_estate_core' => '>=10.0.0',
            'vhs' => '>=6.0.3'
        ),
        'conflicts' => array(
        ),
        'suggests' => array(
        ),
    ),
);